# nzb

[![PyPI - Version](https://img.shields.io/pypi/v/nzb?link=https%3A%2F%2Fpypi.org%2Fproject%2Fnzb%2F)](https://pypi.org/project/nzb/)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/nzb)
![License](https://img.shields.io/github/license/Ravencentric/nzb)
![PyPI - Types](https://img.shields.io/pypi/types/nzb)

![GitHub Build Workflow Status](https://img.shields.io/github/actions/workflow/status/Ravencentric/nzb/release.yml)
![GitHub Tests Workflow Status](https://img.shields.io/github/actions/workflow/status/ravencentric/nzb/tests.yml?label=tests)
[![Codecov Status](https://codecov.io/gh/Ravencentric/nzb/graph/badge.svg?token=FFSOFFOM6J)](https://codecov.io/gh/Ravencentric/nzb)

A [spec](https://sabnzbd.org/wiki/extra/nzb-spec) compliant parser and meta editor for NZB files.

## Installation

`nzb` is available on [PyPI](https://pypi.org/project/nzb/), so you can simply use [pip](https://github.com/pypa/pip) to install it.

```sh
pip install nzb
```

## License

Distributed under the [MIT](https://choosealicense.com/licenses/mit/) License. See [LICENSE](https://github.com/Ravencentric/nzb/blob/main/LICENSE) for more information.
